# bmptoduet
[![PyPI version](https://badge.fury.io/py/bmptoduet.svg)](https://badge.fury.io/py/bmptoduet) Convert Monochrome BMP to Duet3D Menu Image 

For the Duet 12864 menu system - https://duet3d.dozuki.com/Wiki/Duet_2_Maestro_12864_display_menu_system